package com.delta.acs.snapp.gates.web.client.lightstreamer;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Queue;

import com.delta.acs.snapp.gates.web.client.framework.nametoken.GatesNameToken;
import com.delta.acs.snapp.gates.web.client.lightstreamer.setup.LSClientProperties;
import com.delta.acs.snapp.gates.web.client.lightstreamer.setup.LSGWTNonOverWriteTable;
import com.delta.acs.snapp.gates.web.client.lightstreamer.setup.LSGWTResources;
import com.delta.acs.snapp.gates.web.client.lightstreamer.setup.LSGWTSchemaElement;
import com.delta.acs.snapp.gates.web.client.model.departure.FlightInfoVo;
import com.delta.acs.snapp.gates.web.client.ui.GlobalPopups;
import com.delta.acs.snapp.gates.web.client.view.AmsMonitorView;
import com.delta.acs.snapp.gates.web.shared.model.CabinCountTO;
import com.delta.acs.snapp.gates.web.shared.model.FlightObjectTO;
import com.delta.acs.snapp.gates.web.shared.model.FpesFlightLegTO;
import com.google.gwt.core.client.GWT;
import com.gwtplatform.mvp.client.View;

/**
 * This is the NonVisualGWTClient subclass connected to GWT_StockListDemo_Basic
 * UI. <code>onItemUpdate()</code> is overridden in order to feed the HTML page
 * with new data.
 */
public class LSGWTGateTable extends LSGWTNonOverWriteTable {

	/**
	 * Schema array
	 */
	private LSGWTSchemaElement[] schema;

	/**
	 * Group array
	 */
	private String[] group;

	/** GWT dynamic table that contains all the stock quotes */
	private View view;

	public LSGWTGateTable(LSGWTSchemaElement[] schema, String[] group,
			SubscriptionMode subscriptionMode) {
		super(schema, group, subscriptionMode);
		this.schema = schema;
		this.group = group;
	}

	public void setView(View view) {
		this.view = view;
	}

	public View getView() {
		return view;
	}

	static HashMap<String, String> config = LSClientProperties
			.readProperties(((LSGWTResources) GWT.create(LSGWTResources.class))
					.lsconfig().getText());
	/**
	 * Method gets the values from AMS whenever any updates happens
	 * @param ItemId
	 * @param Array of schema
	 * @param Array of Updated values
	 * @return fpesFlightlegId with underscores
	 */
	@Override
	public void onItemUpdate(String itemId, String[] schema, String value[]) {
		//Window.alert("Item ID: "+itemId);
		AmsMonitorView amsMonitorView =  (AmsMonitorView) 
								ViewObjectPool.getView(GatesNameToken.AMSMONITORVIEW);
		if (amsMonitorView != null){
			amsMonitorView.setNewEvent(itemId, schema, value);
		}
		/*Window.alert("ViewObjectPool.getViewComponent()::::"+ViewObjectPool.getViewComponent());*/
		// For flight related AMs changes
		FlightObjectTO flightObjectTO = ViewObjectPool.getCurrentFlight();
		FpesFlightLegTO fpesFlightLegTO = flightObjectTO.getFpesFlightLeg();
		String fpesFlightlegId = fpesFlightLegTO.getFpesFlightLegId();
		String fpesFlightlegIdModified = getModifiedFpesFlightlegId(fpesFlightlegId.trim());
		if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_PIDS")) {
			handlePIDSEvent(itemId, schema, value);
		}
		else {
			List<FlightObjectTO> flightObjectTOs = ViewObjectPool.getFlightObjects();
			for (FlightObjectTO flightObjectsTO : flightObjectTOs){
				FpesFlightLegTO fpesFlightsLegTO = flightObjectsTO.getFpesFlightLeg();
				String fpesFlightslegId = fpesFlightsLegTO.getFpesFlightLegId();
				String fpesFlightslegIdModified = getModifiedFpesFlightlegId(fpesFlightslegId.trim());
				if (itemId.equalsIgnoreCase(fpesFlightslegIdModified+"_PIDS")){
					GatesViewAMS gatesViewAMS = new GatesViewAMS();
					gatesViewAMS.updateFlightInfoTab(itemId, schema, value);
				}
			}
		}
		
		//for AddPassenger Message related AMs Changes
		/*String modifiedItm =  fpesFlightlegIdModified+"_ADDPSGR_"+ViewObjectPool.getGroupSession(fpesFlightlegIdModified+"_ADDPSGR");
		if (itemId.equalsIgnoreCase(modifiedItm)) {
			GatesViewAMS gatesViewAMS = new GatesViewAMS();
			gatesViewAMS.updatePlayBookPassengerDetails(itemId, schema, value);
			
		}*/
		
		//For PlayBook updation
		String playBookUpdate =  fpesFlightlegIdModified+"_PLAYBOOKVALUES";
		if (itemId.equalsIgnoreCase(playBookUpdate)) {
			handlePlayBookValuesEvent(itemId, schema, value);
		}
		//for SOA VolunteerMessage
		String volunteerMessage = fpesFlightlegIdModified+"_SOA_VOLUNTEER_MESSAGE";
		if(itemId.equalsIgnoreCase(volunteerMessage)){
			handleSOAVolunteerMessage(itemId, schema, value);
		}
		//for voluteer Alert
		String volunteerAlert = fpesFlightlegIdModified+"_SOA_VOLUNTEER_ALERT";
		if(itemId.equalsIgnoreCase(volunteerAlert)){
			handleSOAVolunteerAlert(itemId, schema, value);
		}
		//for SOA SNAPPShot Count in SNAPPshot
		String soaSNAPPShotMessage = fpesFlightlegIdModified+"_SOA_SNAPPSHOT_MESSAGE";
		if(itemId.equalsIgnoreCase(soaSNAPPShotMessage)){
			handleSOASNAPPShotMessage(itemId, schema, value);
		}
		
		//for BOARDING Play
		String boardingBinsFull = fpesFlightlegIdModified+"_BOARDING_BINS_FULL";
		if(itemId.equalsIgnoreCase(boardingBinsFull)){
			handleBoardingBinsFullMessage(itemId, schema, value);
		}
		
		//for Snapshot AddPassenger
		String addedItem = fpesFlightlegIdModified+"_SNAPPADDPSGR";
		if (itemId.equalsIgnoreCase(addedItem)) {
			handleSnappAddPsgrEvent(itemId, schema, value);
		}
		//for Payload optimize
		String payloadOptimizeItem = fpesFlightlegIdModified+"_SOA_PAYLOADOPTIMIZED";
		if (itemId.equalsIgnoreCase(payloadOptimizeItem)) {
			handleSOAPayLoadOptEvent(itemId, schema, value);			
		}
		//for Establish Gate Control
		String establishGateControlItem = fpesFlightlegIdModified+"_SOA_ESTABLISHGATECONTROL";
		if (itemId.equalsIgnoreCase(establishGateControlItem)) {
			handleSOAEstablishGateControlEvent(itemId, schema, value);
		}
		//for Payload capacity
		String payloadCapacityItem = fpesFlightlegIdModified+"_SOA_PAYLOADCAPACITY";
		if (itemId.equalsIgnoreCase(payloadCapacityItem)) {
			handleSOAPayLoadCpEvent(itemId, schema, value);
		}
		
		String famMessageItem = fpesFlightlegIdModified+"_FAM_MSGDETAIL";
		if (itemId.equalsIgnoreCase(famMessageItem)) {
			handleFamMsgDetailEvent(itemId, schema, value);
		}
		//for Seat ASSIGN
		String seatAssign = fpesFlightlegIdModified+"_SEATASSIGN";
		if (itemId.equalsIgnoreCase(seatAssign)) {
			handleSeatAssignEvent(itemId, schema, value);
		}
		//for Seat UNASSIGN
		String seatUnAssign = fpesFlightlegIdModified+"_SEATUNASSIGN";
		if (itemId.equalsIgnoreCase(seatUnAssign)) {
//			Window.alert("inside _SEATUNASSIGN_");
			handleSeatUnassignEvent(itemId, schema, value);
		}
		//for SnapShot OnList AddPassenger
		String addedOnListItem = fpesFlightlegIdModified+"_SNAPPONLISTADDPSGR";
		if (itemId.equalsIgnoreCase(addedOnListItem)) {
			handleOnListAddPsgr(itemId, schema, value);
		}
		//for SNAPP SHOT CIList AddPassenger
		String addCIListPsgr = fpesFlightlegIdModified+"_SNAPPCILISTADDPSGR";
		if (itemId.equalsIgnoreCase(addCIListPsgr)) {
			handleCIAddPsgrEvent(itemId, schema, value);
		}
		//for SNAPP SHOT ReservedList AddPassenger
		String addReservedListPsgr = fpesFlightlegIdModified+"_SNAPPRESERVEDLISTADDPSGR";
		if (itemId.equalsIgnoreCase(addReservedListPsgr)) {
			handleRSAddPsgrEvent(itemId, schema, value);
		}
		//for SnapShot SSR Code Updation
		String ssrCodeChange = fpesFlightlegIdModified+"_SSRCODECHANGE";
		if (itemId.equalsIgnoreCase(ssrCodeChange)) {
			handleSSRCodeChng(itemId, schema, value);
		}
		//for Remove Passenger in SNAPP SHOT
		String removePassenger = fpesFlightlegIdModified+"_REMOVEPASSENGER";
		if (itemId.equalsIgnoreCase(removePassenger)) {
			handleRemovePsgrEvent(itemId, schema, value);
		}
		//for SNAPPSHOT PUTBACK PSGR and add pasgr in standby List
		String putBackPsgr = fpesFlightlegIdModified+"_PUTBACKPASSENGER";
		if(itemId.equalsIgnoreCase(putBackPsgr)){
			handlePutbackPsgrEvent(itemId, schema, value);
		}
		String addStbypassenger = fpesFlightlegIdModified+"_ADDSTBYPASSENGER";
		if(itemId.equalsIgnoreCase(addStbypassenger)) {
			handleAddStbyPsgrEvent(itemId, schema, value);
		}
		//for clear Passenger in SNAPP SHOT
		String clearpassenger = fpesFlightlegIdModified+"_CLEARPASSENGER";
		if (itemId.equalsIgnoreCase(clearpassenger)) {
			handleClearPsgrEvent(itemId, schema, value);
		}
		//for RemovePassenger Message related AMs Changes
		String modifiedRemovePassenegrItem= fpesFlightlegIdModified+"_REMOVEPSGR";
		if (itemId.equalsIgnoreCase(modifiedRemovePassenegrItem)) {
				handlePlayBookValuesEvent(itemId, schema, value);
		}
		//for delete passenger in SNAPP SHOT
		String deletePassenger = fpesFlightlegIdModified+"_DELETEPASSENGER";
		if (itemId.equalsIgnoreCase(deletePassenger)) {
			handleDeletePsgrEvent(itemId, schema, value);
		}
		//for Remove ALL passenger in SNAPP SHOT
		String removeAllPassenger = fpesFlightlegIdModified+"_DELETEALL";
		if (itemId.equalsIgnoreCase(removeAllPassenger)) {
			handleDeleteAllPsgrsEvent(itemId, schema, value);
		}
		//for Remove Pax from StandBy List
		String removePassengerFromStandBy = fpesFlightlegIdModified+"_RMVPSGR";
		if (itemId.equalsIgnoreCase(removePassengerFromStandBy)) {
			handleRmvPsgrEvent(itemId, schema, value);
		}
		/*
		 * Added for Priority Code Change in snapp shot
		 */
		String updatePriorityCode = fpesFlightlegIdModified+"_PRIORITYCODECHANGE";
		if (itemId.equalsIgnoreCase(updatePriorityCode)) {
			handlePriorityChgEvent(itemId, schema, value);
		}
		/*
		 * Added for Seat status change in Snapp shot
		 */
		String updateSeatStatus = fpesFlightlegIdModified+"_SEATSTATUSCHANGE";
		if (itemId.equalsIgnoreCase(updateSeatStatus)) {
			handleSeatStatusChg(itemId, schema, value);
		}
		
		String cabiinCapacity = fpesFlightlegIdModified+"_CABIN_CAPACITY_FPES";
		if (itemId.equalsIgnoreCase(cabiinCapacity)) {
			handleCabinCapacity(flightObjectTO,itemId, schema, value);
		}
		
		//for ArrivalFlight Message related AMs Changes
		/*if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_ARRIVALFLIGHT_"+ViewObjectPool.getGroupSession(fpesFlightlegIdModified+"_ARRIVALFLIGHT"))) {
			GatesViewAMS gatesViewAMS = new GatesViewAMS();
			gatesViewAMS.updatePlayBookArrivalData(itemId, schema, value);
			
		}*/
		
		//for BCN Message related AMs Changes
		/*if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_BCN_"+ViewObjectPool.getGroupSession(fpesFlightlegIdModified+"_BCN"))) {
			GatesViewAMS gatesViewAMS = new GatesViewAMS();
			gatesViewAMS.updateBCNData(itemId, schema, value);
			
		}*/
		
		//for FPES Message related AMs Changes
		if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_FPES")) {
			handleFPESEvents(itemId, schema, value);
		}
		// /For Playbook related AMs Changes
		String playColorEvent = fpesFlightlegIdModified+"_PBCOLOREVENT";
		String playCompletionEvent = fpesFlightlegIdModified+"_PBCOMPLETIONEVENT";
		String playIndicatorEvent = fpesFlightlegIdModified+"_PBINDICATOREVENT";
		String playStatusEvent = fpesFlightlegIdModified+"_PBSTATUSEVENT";
		if (itemId.equalsIgnoreCase(playColorEvent) || itemId.equalsIgnoreCase(playCompletionEvent) || itemId.equalsIgnoreCase(playIndicatorEvent)
				|| itemId.equalsIgnoreCase(playStatusEvent)) {
			GatesViewAMS gatesViewAMS = new GatesViewAMS();
			gatesViewAMS.updatePlayBookAppearance(itemId, schema, value);
		} 
		 
		//For Updating Document type in Documents play
		if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_DOCUMENT_TYPE")) {
			handleDocTypeEvent(itemId, schema, value);
		} 
		//For SSR Message related AMs Changes
		/*if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_SSR_"+ViewObjectPool.getGroupSession(fpesFlightlegIdModified+"_SSR"))) {
			GatesViewAMS gatesViewAMS = new GatesViewAMS();
			gatesViewAMS.updatePlayBookSSr(itemId, schema, value);
		}*/
		if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_ADD_VOLUNTEER_LIST")) {
			handleAddVolListEvent(itemId, schema, value);
		}

		if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_DELETE_VOLUNTEER_LIST")) {
			handleDeleteVolListEvent(itemId, schema, value);
		}
		
		if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_CURRENT_OFFER_VOL_LIST")) {
			handleCurrentOfferVolListEvent(itemId, schema, value);
		}
		
		if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_UPDATE_VOLUNTEER_LIST")) {
			if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.VOLUNTEERLIST)) {
				VolunteerViewAMS volunteerViewAMS = new VolunteerViewAMS();
				volunteerViewAMS.updateVolunteerList(itemId, schema, value);
			}
		}
		//for Zones Message related AMs Changes
		if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_SOA_BOARDING")) {
			handleSoaBoardingEvent(itemId, schema, value);
		}
		//for jumpseat related AMS Changes
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_SOA_JUMPSEAT")) {
    	   handleSOAJumpseatEvent(itemId, schema, value);
		}
       //for boardingError related AMS Changes
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_BOARDING_ERROR_PAX_LIST")) {
    	   handleBrdingErrorPaxListEvent(itemId, schema, value);
		}
       //for passengerlist bags checked related AMS Changes
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_PASSENGERLIST_BAGSCHECKED")) {
    	   handlePsgrListBagsChkd(itemId, schema, value);
		}
       //for passengerlist bags unchecked related AMS Changes
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_PASSENGERLIST_BAGSUNCHECKED")) {
    	   handlePsgrListBagsChkd(itemId, schema, value);
		}
       //for passengerlist class changes related AMS Changes
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_PASSENGERLIST_CLASSCHANGE")) {
    	   handlePsgrListClsChngEvent(itemId, schema, value);
		}
       //for passengerlist remote ci changes related AMS Changes
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_PASSENGERLIST_REMOTECICHANGE")) {
    	   handlePsgrRemoteCiEvent(itemId, schema, value);
       }
       //for change in connection
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_ARRFLIGHTLEG")) {
    	   handleArrFlightLegEvent(itemId, schema, value);
       }
       //Update travel doc play
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_SOA_TRAVELDOC")) {
    	   handleTravelDocEvent(itemId, schema, value);
       }

       //for change in gate control message
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_GATE_CONTROL_MESSAGE")) {
    		   GatesViewAMS gatesViewAMS = new GatesViewAMS();
    		   gatesViewAMS.gateControlMessageremovePopup(itemId, schema, value);
       }
       //For seatmap set blcok and break FPES events
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_SEAT_BLOCK_BREAK_LIST")) {
    	   handleSeatBlockBreakList(itemId, schema, value);
        }
       //for BCN Message Event
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_BCN_MESSAGE")) {
    	   handleBCNMessageEvent(itemId, schema, value);
        }
       
       // for transfer standby
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_XFERTOPASSENGER")) {
    	   handleXFERStandbyMessageEvent(itemId, schema, value);
        }
       
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_ADD_REACCOM_LIST")) {
    	   handleAddOrUpdateReaccomPsgrList(itemId, schema, value);
        }
       //for BCN Message Event
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_UPDATE_REACCOM_LIST")) {
    	   handleAddOrUpdateReaccomPsgrList(itemId, schema, value);
        }
       
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_PRI_SEC_FPES")) {    	  
    	  handlePlayDoneButtonDisp(itemId, schema, value);
        }
       
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_FPES_PRIMARY_SECONDARY")) {
    	   handlePrimarySecondaryMessage(itemId, schema, value);
        }
       
       // for transfer standby
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_REMOVE_REACCOM_LIST")) {
    	   handleRemoveReaccomPsgrList(itemId, schema, value);
        }
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"_SOA_REACCOMODATION")) {
    	   handleSOAReacommSeqessage(itemId, schema, value);
        }
       //for pidsConxId
       String pidsConxId = "";
	    List<FlightInfoVo> flightInfoVoList = ViewObjectPool.getFlightInfoList();
	    for (FlightInfoVo flightInfoVo : flightInfoVoList) {
	        if (flightInfoVo.getFpesFlightLegId().equalsIgnoreCase(fpesFlightlegId)) {
	            pidsConxId = flightInfoVo.getPidsConxId();
	            if (itemId.equalsIgnoreCase(pidsConxId+"_PIDS_HEARBEAT_MSG")) {
	                //Window.alert("inside _PIDS_HEARBEAT_MSG");
	                handlePidsHeartBeatMsg(itemId, schema, value);
	             }
	        }
	    }
       
      /* //for STANDBY UPGRADE
       if (itemId.equalsIgnoreCase(fpesFlightlegIdModified+"__STANDBY_UPGRADE"+ViewObjectPool.getGroupSession(fpesFlightlegIdModified+"__STANDBY_UPGRADE"))) {

    	   //update the standby screen
       }  */   
	}

	private void handlePlayDoneButtonDisp(String itemId, String[] schema2,
			String[] value) {
		
		GatesViewAMS gatesViewAMS = new GatesViewAMS();
		gatesViewAMS.handlePlayBookDoneButton(itemId, schema2, value);
		
		
	}

	private void handlePrimarySecondaryMessage(String itemId, String[] schema2,
			String[] value) {
		String wsine = "";
		String userMacId = "";
		for (int i = 0; i < schema.length; i++) {
			
			if(schema[i].equals("SEC_WSINE"))
			{
				wsine = value[i];
			}
		}
		for (int i = 0; i < schema.length; i++) {
			
			if(schema[i].equals("USER_MACHINEID"))
			{
				userMacId = value[i];
			}
		}
		
		String[] splitWsine = wsine.split("/");
		String[] splitUserMachineId = userMacId.split("/");
		String userMachineId = ViewObjectPool.getUser().getUserId()+"_"+ViewObjectPool.getUser().getMachineId();
		boolean status = false;
		for (int i = 0; i < splitWsine.length; i++) {
			String sessionId = splitWsine[i];
			
			if(splitUserMachineId[i].equalsIgnoreCase(userMachineId))
			{
				status = true;
			}
			
		}
		if(status)
		{
			GlobalPopups.showGeneralMsgPopup("Secondary established for the flight");
		}
		// TODO Auto-generated method stub
		
	}
	
	private void handleCabinCapacity(FlightObjectTO flightObjectTO,String itemId, String[] schema2,
			String[] value) {
		
		Queue<CabinCountTO> cabinList = flightObjectTO.getCabinList();
		String cabinId = "";
		String seatCapacity  = "";
		for (int i = 0; i < schema.length; i++) {
			if(schema[i].equals("CABINID"))
			{
				cabinId = value[i];
			}
			if(schema[i].equals("SEAT_CAPACITY"))
			{
				seatCapacity = value[i];
			}
		}
		CabinCountTO cabinCountTO = null;
		for (Iterator iterator = cabinList.iterator(); iterator.hasNext();) {
			cabinCountTO = (CabinCountTO) iterator.next();
			if(cabinId.equals(cabinCountTO.getCabinId()))
			{
				cabinCountTO.setSeatCapacity(Integer.valueOf(seatCapacity));
			}
		}
		// TODO Auto-generated method stub
		
	}
	
	public void handleTravelDocEvent(String itemId, String[] schema,
			String[] value){
		GatesViewAMS gatesView = new GatesViewAMS();
		gatesView.updatePlayBookTravelDoc(itemId, schema, value);
	}


	public void handleRmvPsgrEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
		    seatMapViewAMS.removeFromStandbyList(itemId, schema, value);
		} if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.removePaxFromStandBy(itemId, schema, value);
		} if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.removeStandByPax(itemId, schema, value);
//			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
//		    seatMapViewAMS.removeFromStandbyList(itemId, schema, value);
		}
	}

	public void handleFamMsgDetailEvent(String itemId, String[] schema,
			String[] value) {
		FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
		flightInfoViewAMS.updateFamMsgInFlightNotesArea(itemId, schema, value);
	}

	public void handleSOAPayLoadCpEvent(String itemId, String[] schema,
			String[] value) {
		FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
		flightInfoViewAMS.updateUiNewMaximumCapacity(itemId, schema, value);
	}

	public void handleSOAPayLoadOptEvent(String itemId, String[] schema,
			String[] value) {
		// TODO update payload capacity in snappshot
		FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
		flightInfoViewAMS.updatePayloadOptimizeMsgInFlightNotesArea(itemId, schema, value);
		flightInfoViewAMS.updateUiNewMaximumCapacity(itemId, schema, value);
	}

	public void handleSOAEstablishGateControlEvent(String itemId, String[] schema,
			String[] value)
	{
		FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
		flightInfoViewAMS.updateEstablishGateControlMsgInFlightNotesArea(itemId, schema, value);
	}
	
	public void handlePlayBookValuesEvent(String itemId, String[] schema,
			String[] value) {
			GatesViewAMS gatesViewAMS = new GatesViewAMS();
			gatesViewAMS.updatePlayBookPassengerDetails(itemId, schema, value);
			if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CONNECTIONS)) {
				ConnectionViewAMS connectionViewAMS = new ConnectionViewAMS();
				connectionViewAMS.handleCacelFlightEvent(itemId, schema, value);
			}
	}
	
	public void handleSOAVolunteerMessage(String itemId, String[] schema,
			String[] value) {
		GatesViewAMS gatesViewAMS = new GatesViewAMS();
		gatesViewAMS.updatePlayBookVolunteer(itemId, schema, value);
	}
	
	public void handleSOAVolunteerAlert(String itemId, String[] schema,
			String[] value) {
		GatesViewAMS gatesViewAMS = new GatesViewAMS();
		gatesViewAMS.showVolunteerAlert();
	}
	public void handleSOASNAPPShotMessage(String itemId, String[] schema,
			String[] value) {
		FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
		flightInfoViewAMS.updateSnappShotCount(itemId, schema, value);
	}
	public void handleBoardingBinsFullMessage(String itemId, String[] schema,
			String[] value) {
		GatesViewAMS flightInfoViewAMS = new GatesViewAMS();
		flightInfoViewAMS.updatePlayBookBoarding(itemId, schema, value);
	}
	
	public void handleSOAReacommSeqessage(String itemId, String[] schema,
			String[] value) {
		GatesViewAMS gatesViewAMS = new GatesViewAMS();
		gatesViewAMS.updatePlayBookReaccomm(itemId, schema, value);
	}
	public void handlePIDSEvent(String itemId, String[] schema, String[] value) {
		GatesViewAMS gatesViewAMS = new GatesViewAMS();
		BoardingInformationViewAMS boardingInformationViewAMS = new BoardingInformationViewAMS();
		gatesViewAMS.updatePlayBookProperties(itemId, schema, value);
		gatesViewAMS.updateFlightInfoBar(itemId, schema, value);
		gatesViewAMS.updateFlightInfoTab(itemId, schema, value);
		
		//Update Playbook Percentage
		boardingInformationViewAMS.updatePBFirstClassPercentage(itemId, schema, value);

		// for flightInfoView changes
		FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
		flightInfoViewAMS.updateFlightInfoView(itemId, schema, value);
		flightInfoViewAMS.updateEstimatedTimeInSnappshot(itemId, schema, value);
		
		//for boarding firstclass AMS changes
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.BOARDINGINFORMATION)) {
			
			boardingInformationViewAMS.updateFirstClass(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			//StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			//standByListViewAMS.updateAvailableSeats(itemId, schema, value);

		}
	}

	public void handleBCNMessageEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.BCNLIST)) {
    		   BCNListViewAMS bcnListViewAMS = new BCNListViewAMS();
    		   bcnListViewAMS.handleBCNListViewAMS(itemId, schema, value);
    		   
    	   }
	}

	public void handleSeatBlockBreakList(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN)
    			   || ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)
    			   || ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) 
    	   {
    		   SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
    		   seatMapViewAMS.changeBlockAndBreakStatus(itemId, schema, value);
    	   }
	}

	public void handleBrdingErrorPaxListEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.BOARDINGINFORMATION)) {
    		   BoardingInformationViewAMS boardingInformationViewAMS = new BoardingInformationViewAMS();
    		   boardingInformationViewAMS.addPaxErrorList(itemId, schema, value);
    	   }
	}

	public void handleSOAJumpseatEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.BOARDINGINFORMATION)) {
    		   BoardingInformationViewAMS boardingInformationViewAMS = new BoardingInformationViewAMS();
    		   boardingInformationViewAMS.updateJumpSeat(itemId, schema, value);
    	   }
	}

	public void handleSoaBoardingEvent(String itemId, String[] schema,
			String[] value) {
		BoardingInformationViewAMS boardingInformationViewAMS = new BoardingInformationViewAMS();
		boardingInformationViewAMS.updatePlaybookZonesPercentage(itemId, schema, value);
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.BOARDINGINFORMATION)) {
			boardingInformationViewAMS.updateZones(itemId, schema, value);
		}
	}

	public void handleDocTypeEvent(String itemId, String[] schema,
			String[] value) {
			GatesViewAMS gatesViewAMS = new GatesViewAMS();
			gatesViewAMS.updateDocumentType(itemId, schema, value);
	}

	public void handleDeleteVolListEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.VOLUNTEERLIST)) {
			VolunteerViewAMS volunteerViewAMS = new VolunteerViewAMS();
			volunteerViewAMS.deleteVolunteerList(itemId, schema, value);
		}
	}

	public void handleAddVolListEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.VOLUNTEERLIST)) {
			VolunteerViewAMS volunteerViewAMS = new VolunteerViewAMS();
			volunteerViewAMS.addVolunteerList(itemId, schema, value);
		}
	}

	public void handlePriorityChgEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updatePriorityCode(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.handleStandByViewAMS(itemId, schema, value);
			
//			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
//    	    seatMapViewAMS.changeConnectionIndicator(itemId, schema, value);
		}
	}

	public void handleDeleteAllPsgrsEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateRemoveAllPax(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.removeAllStandByPax(itemId, schema, value);
			
//			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
//    	    seatMapViewAMS.changeConnectionIndicator(itemId, schema, value);
		}
	}

	public void handleDeletePsgrEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateRemovePassenger(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.removeStandByPax(itemId, schema, value);
			
//			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
//    	    seatMapViewAMS.changeConnectionIndicator(itemId, schema, value);
		}
	}

	public void handleClearPsgrEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateRemovePassenger(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.handleStandByViewAMS(itemId, schema, value);
			
//			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
//    	    seatMapViewAMS.changeConnectionIndicator(itemId, schema, value);
		}
	}

	public void handlePutbackPsgrEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updatePutBackPassenger(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.handleStandByViewAMS(itemId, schema, value);
			
		}
	}
	
	public void handleAddStbyPsgrEvent(String itemId, String[] schema,
			String[] value) {
		
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
		    seatMapViewAMS.addToStandbyList(itemId, schema, value);
		}
		
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updatePutBackPassenger(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.handleStandByViewAMS(itemId, schema, value);
		}
	}

	public void handleSnappAddPsgrEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.addPassenger(itemId, schema, value);
		}
		
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateBookingCount(itemId, schema, value);
			flightInfoViewAMS.updateAddPassenger(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CONNECTIONS)) {
			ConnectionViewAMS connectionViewAMS = new ConnectionViewAMS();
			connectionViewAMS.handleAddorUpdatePsgrInConxViewAMS(itemId, schema, value);
			
			ConnectingPaxListViewAMS connectingPaxListViewAMS = new ConnectingPaxListViewAMS();
			connectingPaxListViewAMS.handleConnectingPaxViewAMS(itemId, schema, value);
		} else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handleSeatAssignEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.changeSeatToRs(itemId, schema, value);
		}
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateseatAssign(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
		} else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handleSeatUnassignEvent(String itemId, String[] schema,
			String[] value) {
//		Window.alert("inside handleSeatUnassignEvent");
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.changeSeatToAvailable(itemId, schema, value);
		}
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
		}

		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateseatUnAssign(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CONNECTIONS)) {
//			Window.alert("inside GatesNameToken.CONNECTINGPASSENGERLIST");
			ConnectingPaxListViewAMS connectingPaxListViewAMS = new ConnectingPaxListViewAMS();
			connectingPaxListViewAMS.handleConnectingPaxViewAMS(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.VOLUNTEERLIST)) {
				VolunteerViewAMS volunteerViewAMS = new VolunteerViewAMS();
				volunteerViewAMS.handleReleaseSeatAMS(itemId, schema, value);
		}
		else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handleOnListAddPsgr(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.setSeatOn(itemId, schema, value);
		}
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {		
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
			
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateOnListAddPassenger(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
		} else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handleCIAddPsgrEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.changeSeatToCi(itemId, schema, value);
		}
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateCIListAddPassenger(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
		} else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handleRSAddPsgrEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.changeSeatToRs(itemId, schema, value);
		}
		
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateRSListAddPassenger(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
		} else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handleSSRCodeChng(String itemId, String[] schema, String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.changeSeatSsrs(itemId, schema, value);
		}
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.handlePassengerListAMS(itemId,schema,value);
			
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateOnListAddPassenger(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CONNECTIONS)) {
			ConnectionViewAMS connectionViewAMS = new ConnectionViewAMS();
			connectionViewAMS.hanldeUpdtSSRCntInConxViewAMS(itemId, schema, value);
			
			ConnectingPaxListViewAMS connectingPaxListViewAMS = new ConnectingPaxListViewAMS();
			connectingPaxListViewAMS.handleConnectingPaxViewAMS(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.BCNLIST)) {
			 BCNListViewAMS bcnListViewAMS = new BCNListViewAMS();
			 bcnListViewAMS.handleBCNListViewAMS(itemId, schema, value);
		} else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.handleStdBySSRS(itemId, schema, value);
		}
	}

	public void handleRemovePsgrEvent(String itemId, String[] schema,
			String[] value) {
//		Window.alert("in remove psgr event");
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.changeSeatToAvailable(itemId, schema, value);
		}
		
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.removePassenger(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateBookingCount(itemId, schema, value);
			flightInfoViewAMS.updateRemovePassenger(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.removePassenger(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.removePassenger(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CONNECTIONS)) {
			ConnectionViewAMS connectionViewAMS = new ConnectionViewAMS();
			connectionViewAMS.hanldeRmvOrUpdtPagrCntInConxViewAMS(itemId, schema, value);
			
			ConnectingPaxListViewAMS connectingPaxListViewAMS = new ConnectingPaxListViewAMS();
			connectingPaxListViewAMS.removePassenger(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.ARRIVALFLIGHTS)) {
			ArrivalFlightViewAMS arrivalFlightViewAMS = new ArrivalFlightViewAMS();
			arrivalFlightViewAMS.hanldeArrivalViewAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.BCNLIST)) {
			 BCNListViewAMS bcnListViewAMS = new BCNListViewAMS();
			 bcnListViewAMS.removeBCNPassenger(itemId, schema, value);
		}
	}

	public void handleSeatStatusChg(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
			seatMapViewAMS.changeSeatToCi(itemId, schema, value);
		}
		
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
			PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
			passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
			
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateSeatStatus(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
			SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
			ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
		}
		
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
			CateringViewAMS cateringViewAMS = new CateringViewAMS();
			cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
		} else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handleFPESEvents(String itemId, String[] schema, String[] value) {
		//if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.GATES_PAGE)) {

		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
			FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
			flightInfoViewAMS.updateEstimatedTimeInSnappshot(itemId, schema, value);
		}		
		GatesViewAMS gatesViewAMS = new GatesViewAMS();
		gatesViewAMS.updateFlightHeaderBar(itemId, schema, value);

		gatesViewAMS.updateFlightInfoBar(itemId, schema, value);
		gatesViewAMS.updateFlightInfoTab(itemId, schema, value);

		//}
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CONNECTIONS)) {
			ConnectionViewAMS connectionViewAMS = new ConnectionViewAMS();
			connectionViewAMS.handleFPESConxViewAMS(itemId, schema, value);
		}
		else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.ARRIVALFLIGHTS)) {
			ArrivalFlightViewAMS arrivalFlightViewAMS = new ArrivalFlightViewAMS();
			arrivalFlightViewAMS.handleArrivalFlightFPESEvents(itemId, schema, value);
		}
	}

	public void handlePsgrListBagsChkd(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
    		   PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
    		   passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
    	   }
			
    	   else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
    		   SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
    		   ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
    	   } else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handlePsgrListClsChngEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
    		   PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
    		   passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
    	   }
    	   else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
    		   SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
    		   ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
    	   }
    	   else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
    		   CateringViewAMS cateringViewAMS = new CateringViewAMS();
    		   cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
    	   } else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handlePsgrRemoteCiEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN)
 			   || ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)
 			   || ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) 
 	   		{
    		   SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
    		   seatMapViewAMS.changeSeatToCi(itemId, schema, value);
    	   }
    	   else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {
    		   PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
    		   passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
    	   }
    	   else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.FLIGHTINFO)) {
    		   FlightInfoViewAMS flightInfoViewAMS = new FlightInfoViewAMS();
    		   flightInfoViewAMS.removeFromPassengerReservedList(itemId, schema, value);
    	   }		
    	   else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
    		   SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
    		   ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
    	   }
    	   else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {			
    		   CateringViewAMS cateringViewAMS = new CateringViewAMS();
    		   cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
    	   } else
			handleBCNMessageEvent(itemId, schema, value);
	}

	public void handleArrFlightLegEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATMAPMAIN) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST) ||
				ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			SeatMapViewAMS seatMapViewAMS = new SeatMapViewAMS();
    		   seatMapViewAMS.changeConnectionIndicator(itemId, schema, value);
    	   } 

		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.PASSENGERLIST)) {    	   
    		   PassengerListViewAMS passengerListViewAMS = new PassengerListViewAMS();
    		   passengerListViewAMS.handlePassengerListAMS(itemId, schema, value);
    	   } else  if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SSRCUSTOMERLIST)) {
    		   SSRCustomerListViewAMS ssrCustomerListViewAMS= new SSRCustomerListViewAMS();
    		   ssrCustomerListViewAMS.handleSSRViewAMS(itemId, schema, value);
    	   } else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CATERING)) {
    		   CateringViewAMS cateringViewAMS = new CateringViewAMS();
    		   cateringViewAMS.handleCateringViewAMS(itemId, schema, value);
    	   } else  if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.CONNECTIONS)) {
    		   ConnectionViewAMS connectionViewAMS = new ConnectionViewAMS();
    		   connectionViewAMS.handleAddorUpdatePsgrInConxViewAMS(itemId, schema, value);
    	   } else if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
				StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
				standByListViewAMS.handleStdByConnection(itemId, schema, value);
			}
	}
	
	public void handleXFERStandbyMessageEvent(String itemId, String[] schema,
			String[] value){
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.STANDBYLIST)) {
			StandByListViewAMS standByListViewAMS = new StandByListViewAMS();
			standByListViewAMS.handleStandByViewAMS(itemId, schema, value);
		}
	}
	
	private void handleAddOrUpdateReaccomPsgrList(String itemId, String[] schema,
			String[] value){
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATREACCOMADATION)) {
			ReaccomodationViewAMS reaccomodationViewAMS = new ReaccomodationViewAMS();
			reaccomodationViewAMS.handleReaccomodationAMS(itemId, schema, value);
			GatesViewAMS gatesViewAMS=new GatesViewAMS();
			gatesViewAMS.showEquipmentChangeBox();
		}
	}
	
	private void handleRemoveReaccomPsgrList(String itemId, String[] schema,
			String[] value){
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.SEATREACCOMADATION)) {
			ReaccomodationViewAMS reaccomodationViewAMS = new ReaccomodationViewAMS();
			reaccomodationViewAMS.removeReaccomodationPax(itemId, schema, value);
		}
	}
	
	/**
	 * Replaces white spaces with underscore.
	 * @param fpesFlightlegId with white space
	 * @return fpesFlightlegId with underscores
	 */
	public static String getModifiedFpesFlightlegId(String fpesFlightlegId) {
		return fpesFlightlegId.replace(" ", "_");
	}

	
	public void handleCurrentOfferVolListEvent(String itemId, String[] schema,
			String[] value) {
		if(ViewObjectPool.getViewComponent().equalsIgnoreCase(GatesNameToken.VOLUNTEERLIST)) {
			VolunteerViewAMS volunteerViewAMS = new VolunteerViewAMS();
			volunteerViewAMS.updateCurrentOffer(itemId, schema, value);
		}
	}
	public void handlePidsHeartBeatMsg(String itemId, String[] schema,
	            String[] value) {
		// create a new class to handle pidsheartbeat event
		for (int i = 0; i < value.length; i++) {
            //Window.alert("PIDS_HEARTBEAT_MSG:::SCHEMA:: "+schema[i]+" VALUE::: "+value[i]);
		}
	}

}
