package com.delta.acs.snapp.gates.web.client.lightstreamer.setup;

import java.util.HashMap;

import com.delta.acs.snapp.gates.web.client.lightstreamer.ViewObjectPool;
import com.google.gwt.core.client.JavaScriptObject;

/**
 * LSGWTNonVisualTable has been inspired by the following
 * Lightstreamer forum talk:
 * http://www.lightstreamer.com/vb/showthread.php?t=713
 */

public abstract class LSGWTNonOverWriteTable 
{
    
    /** items update mode */
	
    public enum SubscriptionMode 
    {
        RAW, MERGE, DISTINCT, COMMAND;
    }
    
    /**
     * Opaque JavaScript object containing the NonVisualTable instance.
     */
    
    protected JavaScriptObject nvt;
    
    /**
     * Internal group (item1, item2, item3, etc) elements cache Hash table.
     */
    
    protected HashMap<String, Integer> group = new HashMap<String, Integer>();
    
    /**
     * Internal schema (last_price, ask, bid, etc) elements cache Hash table.
     */
    
    protected HashMap<String, Integer> schema = new HashMap<String, Integer>();
   
    /**
     * Updates feeding mode (Stock-List Demo uses MERGE).
     */
    
    protected String subscriptionMode;
    
    /**
     * LSGWTNonVisualTable abstract class constructor A schema, an item group and a subscription mode needs to be
     * provided.
     * @param schema
     * @param group
     */
    
    public LSGWTNonOverWriteTable(LSGWTSchemaElement[] schema, String[] group,
            SubscriptionMode mode) 
    {
    	try{
    	// adding list of fields (schema)
        for (int i = 0; i < schema.length; i++) 
        {
            String field = schema[i].toString();
            Integer count = this.schema.get(field);
            if (count == null || count == 0) 
            {
                this.schema.put(field, 1);
            } 
            else 
            {
                count = count + 1;
                this.schema.put(field, count);
            }
        }
        // adding list of items to subscribe
        for (int i=0; i < group.length; i++) 
        {
            String item = group[i];
            Integer count = this.group.get(item);
            if (count == null || count == 0) 
            {
                this.group.put(item, 1);
            } else 
            {
                count = count + 1;
                this.group.put(item, count);
            }
        }
        this.subscriptionMode = mode.name();
        
        this.setupNVT();
    	}catch (Exception e) {
    		StringBuffer logStatement = new StringBuffer(3);
    		logStatement.append(LSGWTNonOverWriteTable.class.getName()).append(" : LSGWTNonOverWriteTable() : ").append(e.getMessage());
    		ViewObjectPool.handleLogging(ViewObjectPool.LOGLEVEL_ERROR,logStatement.toString());
		}
    }
    
    /**
    * Instantiate (if needed) the JavaScript NonVisualTable object.
    */
    
   private JavaScriptObject setupNVT() 
   {
	   try{
       if (this.nvt == null) 
       {
           this.nvt = this.initNVT(this.getGroupArray(),
                   this.getSchemaArray(), this.subscriptionMode);
       }
	   }catch (Exception e) {
   		StringBuffer logStatement = new StringBuffer(3);
   		logStatement.append(LSGWTNonOverWriteTable.class.getName()).append(" : setupNVT() : ").append(e.getMessage());
   		ViewObjectPool.handleLogging(ViewObjectPool.LOGLEVEL_ERROR,logStatement.toString());
		}
       return this.nvt;
   }
   
   JavaScriptObject getNVT() 
   {
       return this.nvt;
   }
   
   /**
    * Internal method that returns a new NonVisualTable JavaScript object.
    */
   private native JavaScriptObject initNVT(String[] group, String[] schema,
           String subscriptionMode) /*-{
       var myTable = new $wnd.NonVisualTable(group, schema, subscriptionMode);
       myTable.setRequestedMaxFrequency("unfiltered");
       var that = this;
      // var schemas1 = new Array();
       var j = 0;
       var value =new Array();
       myTable.onItemUpdate = function(item, itemUpdate, itemName)
        { 
        	try{
        		   
   			for (i = 0; i < schema.length; i++) 
   			{

   				if (!itemUpdate.isValueChanged(schema[i]) && !itemUpdate.isSnapshot()) 
                {value[i] = 	itemUpdate.getOldValue(schema[i]);
                }else{                
   					value[i] = 	itemUpdate.getNewValue(schema[i]);
                }

   			}
                // check whether the schema value is changed. If it's not, skip it
                // unless a full data snapshot is being sent.
                
             
      //      if (value != null) 
        //    {
                that.@com.delta.acs.snapp.gates.web.client.lightstreamer.setup.LSGWTNonOverWriteTable::onItemUpdate(Ljava/lang/String;[Ljava/lang/String;[Ljava/lang/String;)(itemName, schema, value);
          //  }     
        	}
        	catch (e){
        	}      
        }       
       return myTable;
   }-*/;
   
   /**
    * This is the callback where item updates arrive. You have to override this abstract
    * method and implement your own UI update logic.
    * @param itemId Lightstreamer item id
    * @param schemaId Lightstreamer schema id (last_price, ask, bid, etc)
    * @param value updated element value
    */
   
   public abstract void onItemUpdate(String itemId, String[] schema, String[] value);
       
   public native void setDataAdapter(String dataAdapter) /*-{
       this.@com.delta.acs.snapp.gates.web.client.lightstreamer.setup.LSGWTNonOverWriteTable::nvt.setDataAdapter(dataAdapter);
   }-*/;
   
   public native void setSnapshotRequired(boolean required) /*-{
       this.@com.delta.acs.snapp.gates.web.client.lightstreamer.setup.LSGWTNonOverWriteTable::nvt.setSnapshotRequired(required);
   }-*/;
    
    /**
     * Return schema elements in String array form.
     */
   
    private String[] getSchemaArray() 
    {
    	if(this.schema == null)
    	{
    		return null;
    	}
    	else
    	{
    		return this.schema.keySet().toArray(new String[0]);
    	}
    }

    /**
     * Return group elements in String array form.
     */
    
    private String[] getGroupArray() 
    {
    	if(this.group == null){
    		return null;
    	}
    	else
    	{
    		return this.group.keySet().toArray(new String[0]);
    	}
    }
    
}
